@@ -40,6 +40,7 @@ __all__ = (
     "PrivateConnectionProvisioningFailureCauseType",
     "PrivateConnectionProvisioningStatusType",
     "S3ConnectorOperatorType",
+    "S3InputFileTypeType",
     "SAPODataConnectorOperatorType",
     "SalesforceConnectorOperatorType",
     "ScheduleFrequencyTypeType",
@@ -225,6 +226,7 @@ S3ConnectorOperatorType = Literal[
     "VALIDATE_NON_ZERO",
     "VALIDATE_NUMERIC",
 ]
+S3InputFileTypeType = Literal["CSV", "JSON"]
 SAPODataConnectorOperatorType = Literal[
     "ADDITION",
     "BETWEEN",
@@ -591,6 +593,7 @@ ServiceName = Literal[
     "opsworkscm",
     "organizations",
     "outposts",
+    "panorama",
     "personalize",
     "personalize-events",
     "personalize-runtime",
