@@ -35,6 +35,7 @@ from .literals import (
     PrivateConnectionProvisioningFailureCauseType,
     PrivateConnectionProvisioningStatusType,
     S3ConnectorOperatorType,
+    S3InputFileTypeType,
     SalesforceConnectorOperatorType,
     SAPODataConnectorOperatorType,
     ScheduleFrequencyTypeType,
@@ -136,6 +137,7 @@ __all__ = (
     "RedshiftDestinationPropertiesTypeDef",
     "ResponseMetadataTypeDef",
     "S3DestinationPropertiesTypeDef",
+    "S3InputFormatConfigTypeDef",
     "S3OutputFormatConfigTypeDef",
     "S3SourcePropertiesTypeDef",
     "SAPODataConnectorProfileCredentialsTypeDef",
@@ -1226,6 +1228,14 @@ class S3DestinationPropertiesTypeDef(
     pass
 
 
+S3InputFormatConfigTypeDef = TypedDict(
+    "S3InputFormatConfigTypeDef",
+    {
+        "s3InputFileType": S3InputFileTypeType,
+    },
+    total=False,
+)
+
 S3OutputFormatConfigTypeDef = TypedDict(
     "S3OutputFormatConfigTypeDef",
     {
@@ -1246,6 +1256,7 @@ _OptionalS3SourcePropertiesTypeDef = TypedDict(
     "_OptionalS3SourcePropertiesTypeDef",
     {
         "bucketPrefix": str,
+        "s3InputFormatConfig": "S3InputFormatConfigTypeDef",
     },
     total=False,
 )
